pulp_python
===========

.. image:: https://travis-ci.org/pulp/pulp_python.svg?branch=3.0-dev
   :target: https://travis-ci.org/pulp/pulp_python

.. image:: https://coveralls.io/repos/pulp/pulp_python/badge.png?branch=3.0-dev
   :target: https://coveralls.io/r/pulp/pulp_python?branch=3.0-dev

A Pulp plugin to support hosting your own pip compatible Python packages.

For more information, please see the `documentation
<https://pulp-python.readthedocs.io/en/latest/>`_ or the `Pulp project page
<https://pulpproject.org>`_.
